.. image:: https://img.shields.io/pypi/v/jaraco.stream.svg
   :target: https://pypi.org/project/jaraco.stream

.. image:: https://img.shields.io/pypi/pyversions/jaraco.stream.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.stream.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.stream/master.svg
   :target: http://travis-ci.org/jaraco/jaraco.stream

Routines for handling streaming data, including a
set of generators for loading gzip data on the fly.

License
=======

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.
